///////////////////////////////////////////////////////////////////////////////
//  untClientForm:                                                           //
//  Form to get arguments for an "Add" call to a TAdder object, call the     //
//  method via an HTTP SOAP proxy object and display the result.             //
//  Also displays the HTTP sent & received by the proxy.                     //
///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
//  Written for the January/February 2001 issue of                           //
//  "uk-bug developer's magazine"                                            //
//  by Rob Bracken                                                           //
//  Bracken Software Limited                                                 //
//  01275 843215                                                             //
///////////////////////////////////////////////////////////////////////////////

unit untClientForm;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ExtCtrls, RzEdit;

type
  TfrmClient = class(TForm)
    lblTitle: TLabel;
    pnlStatus: TPanel;
    pnlMain2: TPanel;
    pnlMain: TPanel;
    lblFirst: TLabel;
    lblSecond: TLabel;
    lblResult: TLabel;
    edtFirst: TEdit;
    edtSecond: TEdit;
    cmdAdd: TButton;
    edtResult: TEdit;
    cmdClose: TButton;
    pnlXML: TPanel;
    mmoRequest: TMemo;
    mmoResponse: TMemo;
    lblRequest: TLabel;
    lblResponse: TLabel;
    procedure cmdCloseClick(Sender: TObject);
    procedure edtFirstChange(Sender: TObject);
    procedure edtSecondChange(Sender: TObject);
    procedure cmdAddClick(Sender: TObject);
  private
    { Private declarations }
    function CheckIntegers: Boolean;
  public
    { Public declarations }
  end;

var
  frmClient: TfrmClient;

implementation

{$R *.DFM}

uses
  untAdderProxy;

function TfrmClient.CheckIntegers: Boolean;
{ Check both of the strings in the Edit boxes to make sure they're valid
  integers}

  function CheckInteger(Text: string): Boolean;
  var
    nTemp: integer;
  begin
    Result := False;
    try
      if Text <> '' then
        nTemp := StrToInt(Text);
      Result := True;
    except
      on EConvertError do
        Exit;
    end;
  end;

begin

  Result := True;

  // Try to convert the first edit box to an integer
  if not CheckInteger(edtFirst.Text) then
  begin
    if edtFirst.Text <> '' then
      pnlStatus.Caption := edtFirst.Text + ' is not a valid integer';
    Result := False;
    Exit;
  end;

  // Try to convert the second edit box to an integer
  if not CheckInteger(edtSecond.Text) then
  begin
    if edtSecond.Text <> '' then
      pnlStatus.Caption := edtSecond.Text + ' is not a valid integer';
    Result := False;
    Exit;
  end;

end;

procedure TfrmClient.cmdCloseClick(Sender: TObject);
begin
  Self.Close;
end;

procedure TfrmClient.edtFirstChange(Sender: TObject);
begin
  // Clear the status message
  pnlStatus.Caption := '';
  // Clear the result
  edtResult.Text := '';
  // Test any input to make sure it's a valid integer
  cmdAdd.Enabled := CheckIntegers;
end;

procedure TfrmClient.edtSecondChange(Sender: TObject);
begin
  // Clear the status message
  pnlStatus.Caption := '';
  // Clear the result
  edtResult.Text := '';
  // Test any input to make sure it's a valid integer
  cmdAdd.Enabled := CheckIntegers;
end;

procedure TfrmClient.cmdAddClick(Sender: TObject);
{ Convert the edit strings to integers, add them together and display the
  result }
var
  taTemp: TAdder;
begin

  // Clear the HTTP memos
  mmoRequest.Clear;
  mmoResponse.Clear;

  // Add the two numbers together and display the results
  taTemp := TAdder.Create;
  try
    edtResult.Text := taTemp.Add(StrToInt(edtFirst.Text),
                                          StrToInt(edtSecond.Text));
  finally
    taTemp.Free;
  end;

end;

end.
